//jQuery zoom and draggable gallery plugin v1.3
//Author: Simon Battersby, www.simonbattersby.com
//Plugin page http://www.simonbattersby.com/blog/jquery-plugin-zoom-draggable-image-gallery/


(function( $ ){

  $.fn.orangegallery = function( options ) {  

    var settings = {//defaults
	borderColour:'black',
	borderWidth : 5,
	caption:true,
	allowMany:false,
	captionOpacity:0.7,
	captionPosition: 'bottom',
	captionTextColour: 'white',
	draggable: false
    };
	
	return this.each(function() {        
      if ( options ) { 
        $.extend( settings, options );
      }
		var $holder = $(this).addClass('og_container');//assign a class to the container to set position relative
		$holder.data('topZIndex',2);//initialise zIndex
		var containertop = $holder.offset().top;
		var containerleft = $holder.offset().left;//read top and left coords of container
      	$holder.find('img').each(function(){
			$(this).after($(this).clone());//clone an image
			$(this).addClass('og_thumb');
			$(this).next().addClass('og_largeimg');
		});
		$('.og_largeimg').each(function(){//for cloned large images
			$(this).load(function(){//wait until the image is loaded for Webkit and Opera
				$(this).css({width:'auto',height:'auto',border:'none',padding:0,margin:0,top:'auto',left:'auto',bottom:'auto',right:'auto'})//reset everything
				 	   .removeAttr('width')
					   .removeAttr('height')//remove any widths and height restrictions
					   .data({'width':$(this).outerWidth()+2*settings.borderWidth,'height':$(this).outerHeight()+2*settings.borderWidth})//store base data to avoid IE issues
					   .hide();
				$(this).css({borderColor:settings.borderColour,borderWidth:settings.borderWidth,borderStyle:'solid'});//apply styling to large image, here to prevent the border being visible in IE6 on load
			});
			$(this).wrap('<div class="og_imgwrap">');
			if(settings.caption) $(this).after('<p class="og_caption">'+$(this).attr('title'));//add caption, reading from title
		});
		$('.og_imgwrap').append('<p class="og_close">Close</p>');
		$('.og_caption,.og_close').css({margin:0,padding:0,border:'none',backgroundColor:settings.borderColour,color:settings.captionTextColour,opacity:0});//reset any margins and apply the required settings
		if (settings.draggable) $('.og_imgwrap').draggable({cursor:'move',start:function(){$(this).css({zIndex:$holder.data('topZIndex')});$holder.data('topZIndex',$holder.data('topZIndex')+1);}});
		$('.og_thumb').on('click',function(){
			if(!$(this).hasClass('og_currentthumb')){//do nothing if the corresponding large image is already shown
				$(this).addClass('og_currentthumb');
				if(!settings.allowMany){
					$('.og_currentimg').fadeOut('slow');
					$('.og_currentimg').next('.og_caption').hide();
				}
				$('.og_currentimg').removeClass('og_currentimg');
				var startleft = $(this).offset().left + (0.5*($(this).width()))-containerleft;//calculate centre of the thumbnail
				var starttop = $(this).offset().top + (0.5*($(this).height()))-containertop;
				$(this).data({'startleft':startleft,'starttop':starttop});//store the data for use later
				$(this).next().css({zIndex:$holder.data('topZIndex'),left:startleft+'px',top:starttop+'px'});
				var finishleft = startleft-0.5*($(this).next().find('.og_largeimg').data('width'));//calculate final positions
				var finishtop= starttop-0.5*($(this).next().find('.og_largeimg').data('height'));
				if(finishleft+containerleft<10) finishleft = 10-containerleft ;//don't have the large image off the left of the viewport 
				if (finishleft+containerleft+$(this).next().find('.og_largeimg').data('width')>$(window).width()) finishleft = $(window).width() - $(this).next().find('.og_largeimg').data('width') -containerleft -20;//or the right of the viewport
				if (finishtop+containertop+$(this).next().find('.og_largeimg').data('height')>$(window).height()+$(window).scrollTop()) finishtop = $(window).height() +$(window).scrollTop() - $(this).next().find('.og_largeimg').data('height') -containertop-20;//or the bottom of the viewport
				if (containertop+finishtop<$(window).scrollTop()+10) finishtop = $(window).scrollTop()+10-containertop;//or off the top of the viewport - do this last as we'd rather be off the bottom than the top if the viewport is small
				$(this).next().find('.og_largeimg').addClass('og_currentimg');
				$(this).next().animate({left:finishleft+'px',top:finishtop+'px'},400);
				$(this).next().find('.og_largeimg').animate({opacity:1,height:'show'},400,function(){//animate
					$(this).next('.og_caption').width($(this).innerWidth()-5);//set width of the caption here, so we can use the height in the next line
					if(settings.captionPosition == 'bottom'){
						$(this).next('.og_caption').css({paddingLeft:settings.borderWidth+5+'px',paddingBottom:settings.borderWidth+5+'px',paddingTop:'5px'});//for caption at the bottom
						$(this).next('.og_caption')
							   .css({zIndex:$holder.data('topZIndex'),left:0,top:$(this).data('height')-$(this).next().outerHeight()+'px',opacity:0})//set start position for animation
							   .show()
							   .animate({opacity:settings.captionOpacity},'fast',function(){$(this).parent().addClass('og_closeable');});//fade it in
						$(this).parent().find('.og_close').css({paddingLeft:'5px',paddingBottom:'5px',paddingRight:settings.borderWidth+5+'px',paddingTop:settings.borderWidth+5+'px',right:0,top:0,opacity:0}).show();//set 'close' position
					}
					else if(settings.captionPosition == 'top'){
						$(this).next('.og_caption').css({paddingLeft:settings.borderWidth+5+'px',paddingTop:settings.borderWidth+5+'px',paddingBottom:'5px'});//for caption at the bottom
						$(this).next('.og_caption')
							   .css({zIndex:$holder.data('topZIndex'),left:0,top:0,opacity:0})//set start position for animation
							   .show()
							   .animate({opacity:settings.captionOpacity},'fast',function(){$(this).parent().addClass('og_closeable');})//fade it in
						$(this).parent().find('.og_close').css({paddingTop:'5px',paddingLeft:'5px',paddingRight:settings.borderWidth+5+'px',paddingBottom:settings.borderWidth+5+'px',right:0,bottom:0,opacity:0}).show();//set 'close' positions
					}
					$holder.data('topZIndex',$holder.data('topZIndex')+1);//increment our zIndex counter so they layer correctly
				});
				$holder.data('topZIndex',$holder.data('topZIndex')+1);//and again
			}
			return false;//prevent any default behaviour
		}); 
		$('.og_largeimg').parent().hover(function(){$(this).find('.og_close').animate({opacity:settings.captionOpacity})},function(){$(this).find('.og_close').animate({opacity:0})});
		$('.og_caption a').on('click',function(event){//allow clicks on links in captions
			event.stopPropagation();
		});
		$('.og_imgwrap').on('click',function(){
			if($(this).hasClass('og_closeable')){
				$(this).removeClass('og_closeable');
				$(this).find('.og_caption').hide();//hide the caption
				$(this).find('.og_close').hide();//hide the close caption
				$(this).prev().removeClass('og_currentthumb');
				$(this).animate({left:$(this).prev('.og_thumb').data('startleft'),top:$(this).prev().data('starttop')},'slow');
				$(this).find('.og_largeimg').animate({opacity:0,width:'hide',height:'hide'},'slow').removeClass('og_currentimg');//reverse the animation
			}
			return false;//prevent any default behaviour
		}); 
		$(window).resize(function() {//reset the container variables if the window is resized
			containertop = $holder.offset().top;
			containerleft = $holder.offset().left;//read top and left coords of container
		});
    });

  };
})( jQuery );
